@@ -23,4 +23,4 @@ class OpenfabricStarter:
         service = OpenfabricService(app)
         service.install_rest('/app')
         service.install_socket('/app')
-        # service.run(debug=debug, host=host)
+        service.run(debug=debug, host=host)
